@@ -1,5 +1,3 @@
-require 'nokogumbo'
-
 class Premailer
   module Adapter
     # Nokogiri adapter
@@ -63,13 +61,21 @@ class Premailer
 
           declarations = []
           style.scan(/\[SPEC\=([\d]+)\[(.[^\]\]]*)\]\]/).each do |declaration|
-            rs = CssParser::RuleSet.new(nil, declaration[1].to_s, declaration[0].to_i)
-            declarations << rs
+            begin
+              rs = CssParser::RuleSet.new(nil, declaration[1].to_s, declaration[0].to_i)
+              declarations << rs
+            rescue ArgumentError => e
+              raise e if @options[:rule_set_exceptions]
+            end
           end
 
           # Perform style folding
           merged = CssParser.merge(declarations)
-          merged.expand_shorthand!
+          begin
+            merged.expand_shorthand!
+          rescue ArgumentError => e
+            raise e if @options[:rule_set_exceptions]
+          end
 
           # Duplicate CSS attributes as HTML attributes
           if Premailer::RELATED_ATTRIBUTES.has_key?(el.name) && @options[:css_to_attributes]
@@ -125,13 +131,13 @@ class Premailer
           doc.search("a[@href^='#']").each do |el|
             target = el.get_attribute('href')[1..-1]
             targets << target
-            el.set_attribute('href', "#" + Digest::MD5.hexdigest(target))
+            el.set_attribute('href', "#" + Digest::SHA256.hexdigest(target))
           end
           # hash ids that are links target, delete others
           doc.search("*[@id]").each do |el|
             id = el.get_attribute('id')
             if targets.include?(id)
-              el.set_attribute('id', Digest::MD5.hexdigest(id))
+              el.set_attribute('id', Digest::SHA256.hexdigest(id))
             else
               el.remove_attribute('id')
             end
@@ -233,11 +239,6 @@ class Premailer
             thing.gsub! entity, replacement
           end
         end
-        # Default encoding is ASCII-8BIT (binary) per http://groups.google.com/group/nokogiri-talk/msg/0b81ef0dc180dc74
-        # However, we really don't want to hardcode this. ASCII-8BIT should be the default, but not the only option.
-        if thing.is_a?(String) and RUBY_VERSION =~ /1.9/
-          thing = thing.force_encoding(@options[:input_encoding]).encode!
-        end
         doc = if @options[:html_fragment]
           ::Nokogiri::HTML5.fragment(thing)
         else
